# django-typed-perms

A package to enhance your DX on Django's permission system.

You can read the full documentation of this project at:

[django-typed-perms docs](https://leandrodesouzadev.github.io/django-typed-perms/)
